import { ChangeDetectorRef, Component, OnInit, TemplateRef, ViewChild } from '@angular/core';
import { AppraisalModel, MyAppraisalModel } from 'src/app/shared/model/appraisal.model';
import { EmployeeModel, MyEmployeeModel } from 'src/app/shared/model/employee.model';
import { AppraisalService } from 'src/app/shared/services/appraisal.service';
import { EmployeeService } from 'src/app/shared/services/employee.service';
import Swal from 'sweetalert2';

export interface Data2Model {
  code: string,
  name: string,
  bi: BiModel[],
}
export interface BiModel {
  name: string,
  tools: string[],
  degree: string
}

@Component({
  selector: 'app-self-evaluation',
  templateUrl: './self-evaluation.component.html',
  styleUrls: ['./self-evaluation.component.scss']
})
export class SelfEvaluationComponent implements OnInit {

  pathTitle = ['การประเมินผล', 'ประเมินตนเอง']

  hoveredCode: string | null = null;
  dataList3: Data2Model[] = [
    {
      code: "CC-01",
      name: "จิตสำนึกด้านความปลอดภัยและคุณภาพ (Safety & Quality)",
      bi: [{
        name: "สอนงานด้านความปลอดภัย และคุณภาพของบริษัทให้กับพนักงานในหน่วยงาน",
        tools: ["O"],
        degree: "4"
      }, {
        name: "ติดตามและปรับปรุงการทำงานด้านความปลอดภัยและคุณภาพของทีมงาน",
        tools: ["O", "D"],
        degree: "5"
      }],
    },
    {
      code: "CC-02",
      name: "การทำงานเป็นทีมแบบ TAT (TAT Teamwork)",
      bi: [{
        name: "คิดวิเคราะห์เพื่อแก้ปัญหาด้านความปลอดภัยและคุณภาพในหน่วยงานที่รับผิดชอบ",
        tools: ["O", "D"],
        degree: "5"
      }, {
        name: "นำเสนอและจัดทำรายงานด้านความปลอดภัยและคุณภาพทั้งภาษาไทยและภาษาอังกฤษ",
        tools: ["O"],
        degree: "2"
      },
      {
        name: "สอนงาน และพัฒนาทีมงานให้เกิดการทำงานเป็นทีม โดยยึดเป้าหมายเดียวกัน (TAT Goal) และคำนึงถึง ความต้องการของลูกค้าเป็นหลัก (Next Customer)",
        tools: ["O"],
        degree: "2"
      },
      {
        name: "สนับสนุนทีมงานให้ดำเนินการตามเป้าหมายของทีม และสิ่งที่ตนเองได้รับมอบหมาย",
        tools: ["O", "D"],
        degree: "4"
      },
      {
        name: "วิเคราะห์และแก้ไขปัญหาที่เกิดจากการทำงานเป็นทีม รวมถึงการควบคุมดูแลให้เป็นไปตามเป้าหมาย",
        tools: ["O"],
        degree: "5"
      },
      {
        name: "สื่อสารเพื่อสร้างความเข้าใจ และรับฟังความคิดเห็น ของสมาชิกในทีม ชื่นชมทีมงานแต่ละคนที่เป็น ส่วนหนึ่งในความสำเร็จของทีมร่วมกัน",
        tools: ["O", "D"],
        degree: "5"
      }],
    }
  ]

  dataList4: {
    score: string[],
    condition: string[],
    e: string,
    a: string,
    gap: string
  }[] = [{
    score: ["หากได้คะแนน 90 - 100% ถือว่า Gap +1", "หากได้คะแนน 80 - 89% ถือว่า ไม่มี Gap", "หากได้คะแนน 60 - 79% ถือว่า Gap - 1", "หากได้คะแนน 40 - 59% ถือว่า Gap -", "หากได้คะแนน 0 - 39% ถือว่า Gap - 3"],
    condition: ["1.หากได้คะแนนสูงกว่า 80% แต่มี 3 2 หรือ 1 ด้วย ถือว่า Gap -1", "2.หากได้คะแนนต่ำกว่า 80% แต่มี 4 และ 5 ให้คิด Gap ตาม %", "3.คะแนนต่ำกว่า 80% แต่มี 2 และ 1 ให้คิด Gap ตาม %"],
    e: "4",
    a: "3",
    gap: "-1"
  }]
  @ViewChild('selfEvaluation1_2', { static: true }) selfEvaluation1_2!: TemplateRef<any>;
  @ViewChild('selfEvaluation1_2Edit', { static: true }) selfEvaluation1_2Edit!: TemplateRef<any>;
  currentTemplate: TemplateRef<any> = this.selfEvaluation1_2

  appraisalCompentency: { loading: boolean, select: AppraisalModel, dataList: { check: boolean, data: AppraisalModel }[] } = { loading: false, select: new MyAppraisalModel(), dataList: [] }
  appraisalPms: { loading: boolean, select: AppraisalModel, dataList: { check: boolean, data: AppraisalModel }[] } = { loading: false, select: new MyAppraisalModel(), dataList: [] }
  employee: { loading: boolean, data: EmployeeModel } = { loading: false, data: new MyEmployeeModel() }
  appraisalCompentencyForm: { loading: boolean, select: AppraisalModel, dataList: { check: boolean, data: AppraisalModel }[] } = { loading: false, select: new MyAppraisalModel(), dataList: [] }
  constructor(private appraisalService: AppraisalService,
    private employeeService: EmployeeService,
    private cdr: ChangeDetectorRef
  ) {
  }
  ngOnInit(): void {
    this.currentTemplate = this.selfEvaluation1_2
    this.getProfile()
    this.getAppraisalCompentencyList()
  }
  getProfile() {
    this.employee.loading = true
    this.employeeService.getProfile().subscribe({
      next: response => {
        this.employee.data = new MyEmployeeModel(response)
        this.employee.loading = false
        this.cdr.detectChanges()
      }, error: error => {
        this.employee.loading = false
        this.cdr.detectChanges()
      }
    })
  }
  getAppraisalCompentencyList() {
    this.appraisalCompentency.loading = true
    this.appraisalService.getList().subscribe({
      next: response => {
        this.appraisalCompentency.dataList = response.map(x => ({ check: false, data: new MyAppraisalModel(x) }))
        this.appraisalCompentency.loading = false
        this.cdr.detectChanges()
      }, error: error => {
        this.appraisalCompentency.loading = false
        this.cdr.detectChanges()
      }
    })
  }
  appraisalCompentencyFilter() {
    return this.appraisalCompentency.dataList
  }
  getAppraisalCompentencyFrom() {
    this.appraisalCompentency.loading = true
    this.appraisalService.getList().subscribe({
      next: response => {
        this.appraisalCompentency.dataList = response.map(x => ({ check: false, data: new MyAppraisalModel(x) }))
        this.appraisalCompentency.loading = false
        this.cdr.detectChanges()
      }, error: error => {
        this.appraisalCompentency.loading = false
        this.cdr.detectChanges()
      }
    })
  }
  appraisalPmsFilter() {
    return this.appraisalPms.dataList
  }
  dataList3Filter() {
    return this.dataList3
  }
  showTools(data: string[]) {
    return data.join("/")
  }

  saveDraft() {
    Swal.fire({
      iconHtml: `
          <div class="flex items-center justify-center rounded-full !h-80px !w-80px" style="background-color: #E8F8EE;">
              <svg width="39" height="39" viewBox="0 0 39 39" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <rect width="39" height="39" fill="#D2D2D2"/>
                  <g id="Component">
                      <g id="alert cart">
                          <g id="mdi:file-export">
                              <circle cx="22.5" cy="19.5" r="33.5" fill="#E8F8EE"/>
                              <path d="M9.75 3.25C8.88805 3.25 8.0614 3.59241 7.4519 4.2019C6.84241 4.8114 6.5 5.63805 6.5 6.5V32.5C6.5 33.362 6.84241 34.1886 7.4519 34.7981C8.0614 35.4076 8.88805 35.75 9.75 35.75H29.25C30.112 35.75 30.9386 35.4076 31.5481 34.7981C32.1576 34.1886 32.5 33.362 32.5 32.5V13L22.75 3.25M21.125 5.6875L30.0625 14.625H21.125M14.5113 19.8575H26V31.3463L22.555 27.9013L17.9563 32.5L13.3575 27.9013L17.9563 23.3188" 
                              fill="#1DBE5A"/>
                          </g>
                      </g>
                  </g>
              </svg>
          </div>
          `,
      title: 'บันทึกแบบร่าง',
      text: 'คุณต้องการบันทึกแบบร่างของการประเมินนี้ใช่หรือไม่',
      showCancelButton: true,
      confirmButtonText: 'ยืนยันการบันทึก',
      cancelButtonText: 'ย้อนกลับ',
      customClass: {
        title: '!swal2-title-mt-20px',
        actions: '!swal2-actions-mt-20px',
        icon: '!swal2-icon-no-border',
        confirmButton: '!swal2-button-bg-green',
        cancelButton: '!swal2-button-bg-gray',
      },
    }).then((result) => {
      if (result.isConfirmed) {
        Swal.fire({
          title: 'บันทึกสำเร็จ!',
          text: 'การประเมินของคุณถูกบันทึกแล้ว',
          icon: 'success',
          customClass: {
            confirmButton: '!swal2-button-bg-green',
          }
        });
      } else if (result.dismiss === Swal.DismissReason.cancel) {
        Swal.fire({
          title: 'ยกเลิก!',
          text: 'การบันทึกถูกยกเลิก',
          icon: 'error',
          customClass: {
            confirmButton: '!swal2-button-bg-danger',
          }
        });
      }
    });
  }

  convertDate(dateString: string): string {
    const date = new Date(dateString);
    return date.toLocaleDateString('th-TH', { day: 'numeric', month: 'long', year: 'numeric' });
  }

}
